==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/link/lang/es-mx.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'es-mx', {
	acccessKey: 'Llave de acceso',
	advanced: 'Avanzada',
	advisoryContentType: 'Tipo de contenido consultivo',
	advisoryTitle: 'Título asesor',
	anchor: {
		toolbar: 'Ancla',
		menu: 'Editar ancla',
		title: 'Propiedades del ancla',
		name: 'Nombre del ancla',
		errorName: 'Escriba el nombre del ancla',
		remove: 'Remover ancla'
	},
	anchorId: 'Por Id del elemento',
	anchorName: 'Por nombre del ancla',
	charset: 'Recurso relacionado Charset',
	cssClasses: 'Clases de estilo de hoja',
	download: 'Forzar la descarga',
	displayText: 'Mostrar texto',
	emailAddress: 'Dirección de correo electrónico',
	emailBody: 'Cuerpo del mensaje',
	emailSubject: 'Asunto del mensaje',
	id: 'Id',
	info: 'Información del enlace',
	langCode: 'Código del idioma',
	langDir: 'Dirección del idioma',
	langDirLTR: 'Izquierda a Derecha (LTR)',
	langDirRTL: 'Derecha a Izquierda (RTL)',
	menu: 'Editar enlace',
	name: 'Nombre',
	noAnchors: '(No hay anclas disponibles en el documento)',
	noEmail: 'Escriba la dirección de correo electrónico',
	noUrl: 'Escriba la URL del enlace',
	other: '<other>',
	popupDependent: 'Dependiente (Netscape)',
	popupFeatures: 'Ventana emergente',
	popupFullScreen: 'Pantalla completa (IE)',
	popupLeft: 'Posición Izquierda',
	popupLocationBar: 'Ubicación de la barra',
	popupMenuBar: 'Barra de menú',
	popupResizable: 'Redimensionable',
	popupScrollBars: 'Barras de desplazamiento',
	popupStatusBar: 'Barra de estado',
	popupToolbar: 'Barra de herramienta',
	popupTop: 'Posición superior',
	rel: 'Relación',
	selectAnchor: 'Selecciona un ancla',
	styles: 'Estilo',
	tabIndex: 'Indice de tabulación',
	target: 'Objetivo',
	targetFrame: '<frame>',
	targetFrameName: 'Nombre del marco de destino',
	targetPopup: '<popup window>',
	targetPopupName: 'Nombre de ventana emergente',
	title: 'Enlace',
	toAnchor: 'Enlace al ancla en el texto',
	toEmail: 'Correo electrónico',
	toUrl: 'URL',
	toolbar: 'Enlace',
	type: 'Tipo de enlace',
	unlink: 'Desconectar',
	upload: 'Subir'
} );

==> ldap-account-manager_7.7.orig.tar.bz2: ldap-account-manager-7.7/templates/lib/extra/ckeditor/plugins/link/lang/es-mx.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'es-mx', {
	acccessKey: 'Llave de acceso',
	advanced: 'Avanzada',
	advisoryContentType: 'Tipo de contenido consultivo',
	advisoryTitle: 'Título asesor',
	anchor: {
		toolbar: 'Ancla',
		menu: 'Editar ancla',
		title: 'Propiedades del ancla',
		name: 'Nombre del ancla',
		errorName: 'Escriba el nombre del ancla',
		remove: 'Remover ancla'
	},
	anchorId: 'Por Id del elemento',
	anchorName: 'Por nombre del ancla',
	charset: 'Recurso relacionado Charset',
	cssClasses: 'Clases de estilo de hoja',
	download: 'Forzar la descarga',
	displayText: 'Mostrar texto',
	emailAddress: 'Dirección de correo electrónico',
	emailBody: 'Cuerpo del mensaje',
	emailSubject: 'Asunto del mensaje',
	id: 'Id',
	info: 'Información del enlace',
	langCode: 'Código del idioma',
	langDir: 'Dirección del idioma',
	langDirLTR: 'Izquierda a Derecha (LTR)',
	langDirRTL: 'Derecha a Izquierda (RTL)',
	menu: 'Editar enlace',
	name: 'Nombre',
	noAnchors: '(No hay anclas disponibles en el documento)',
	noEmail: 'Escriba la dirección de correo electrónico',
	noUrl: 'Escriba la URL del enlace',
	noTel: 'Please type the phone number', // MISSING
	other: '<other>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dependiente (Netscape)',
	popupFeatures: 'Ventana emergente',
	popupFullScreen: 'Pantalla completa (IE)',
	popupLeft: 'Posición Izquierda',
	popupLocationBar: 'Ubicación de la barra',
	popupMenuBar: 'Barra de menú',
	popupResizable: 'Redimensionable',
	popupScrollBars: 'Barras de desplazamiento',
	popupStatusBar: 'Barra de estado',
	popupToolbar: 'Barra de herramienta',
	popupTop: 'Posición superior',
	rel: 'Relación',
	selectAnchor: 'Selecciona un ancla',
	styles: 'Estilo',
	tabIndex: 'Indice de tabulación',
	target: 'Objetivo',
	targetFrame: '<frame>',
	targetFrameName: 'Nombre del marco de destino',
	targetPopup: '<popup window>',
	targetPopupName: 'Nombre de ventana emergente',
	title: 'Enlace',
	toAnchor: 'Enlace al ancla en el texto',
	toEmail: 'Correo electrónico',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Enlace',
	type: 'Tipo de enlace',
	unlink: 'Desconectar',
	upload: 'Subir'
} );
